.. highlight:: python

Machine Learning Algorithms
***************************

Ibmdbpy is a wrapper for machine-learning algorithms that are provided by Db2 stored procedures. These include K-means, naive Bayes, and association rules, but any others that are also provided by Db2 can also be used.

.. toctree::
	kmeans.rst
	naive_bayes.rst
	association_rules.rst

